# -*- coding: utf-8 -*-
# Copyright © 2006 Lateef Alabi-Oki
#
# This file is part of Scribes.
#
# Scribes is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Scribes is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Scribes; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

from gettext import gettext as _
msg0001 = _("No paragraph found")
msg0002 = _("No text found")
msg0003 = _("Moved to previous paragraph")
msg0004 = _("No previous paragraph")
msg0005 = _("Moved to next paragraph")
msg0006 = _("No next paragraph")
msg0007 = _("Selected paragraph")
msg0008 = _("Reflowed selected text")
msg0009 = _("Reflowed paragraph")
msg0010 = _("Cannot perform operation in readonly mode")
msg0011 = _("Para_graph")
msg0012 = _("_Previous Paragraph")
msg0013 = _("_Next Paragraph")
msg0014 = _("_Reflow Paragraph")
msg0015 = _("_Select Paragraph")
